package com.monnit.mine.SampleMineApplication;

import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import java.util.concurrent.CopyOnWriteArrayList;

import com.monnit.mine.MonnitMineAPI.Gateway;
import com.monnit.mine.MonnitMineAPI.Sensor;
import com.monnit.mine.MonnitMineAPI.enums.eFirmwareGeneration;
import com.monnit.mine.MonnitMineAPI.enums.eGatewayType;
import com.monnit.mine.MonnitMineAPI.enums.eSensorApplication;
import com.monnit.mine.MonnitMineAPI.iExternalDeviceStorage;

public class ExternalDeviceStorageHandler implements iExternalDeviceStorage {

    @Override
    public Gateway FindGateway(int gatewayID  ) {
        try {
            //Really you would look up gatewayType from DB
            //But for simple example we're hard coding type to USB
            return new Gateway(gatewayID, eGatewayType.USBService);
        } catch (Exception ex) {
            Logger.getLogger(ExternalDeviceStorageHandler.class.getName()).log(Level.SEVERE, null, ex);
        }

        return null;

    }

    @Override
    public Sensor FindSensor(int sensorID) {
        try {
            //Really you would look up sensorType from DB
            //But for simple example we're hard coding eSensorApplication to Temperature if sensorID is 101 else everything will be a button
            if (sensorID == 101) {
                return new Sensor(sensorID, eSensorApplication.Temperature, "2.3.0.0", eFirmwareGeneration.Commercial);
            } else {
                return new Sensor(sensorID, eSensorApplication.Button, "2.3.0.0", eFirmwareGeneration.Commercial);
            }
        } catch (Exception ex) {
            Logger.getLogger(ExternalDeviceStorageHandler.class.getName()).log(Level.SEVERE, null, ex);
        }

        return null;

    }

    @Override
    public List<Sensor> FindSensorsByGateway(int gatewayID) {

        try {
            //Really you would look up SensorType from DB
            //But for simple example we're hard coding type to USB
            List<Sensor> list = new CopyOnWriteArrayList<Sensor>();

            list.add(FindSensor(101));
            list.add(FindSensor(711));

            return list;
        } catch (Exception ex) {
            Logger.getLogger(ExternalDeviceStorageHandler.class.getName()).log(Level.SEVERE, null, ex);
        }

        return null;

    }

    @Override
    public List<Gateway> FindGatewaysBySensor(int sensorID) {

        try {
            //Really you would look up SensorType from DB
            //But for simple example we're hard coding type to USB
            List<Gateway> list = new CopyOnWriteArrayList<Gateway>();
            list.add(FindGateway(109518));
            return list;
        } catch (Exception ex) {
            Logger.getLogger(ExternalDeviceStorageHandler.class.getName()).log(Level.SEVERE, null, ex);
        }

        return null;

    }

}
